@@ -1,6 +1,20 @@
 import typing
 from .base_category import BaseCategory
-from vkbottle_types.responses import orders
+from vkbottle_types.responses.orders import (
+    CancelSubscriptionResponse,
+    ChangeStateResponse,
+    GetAmountResponse,
+    GetByIdResponse,
+    GetResponse,
+    GetUserSubscriptionByIdResponse,
+    GetUserSubscriptionsResponse,
+    GetUserSubscriptionsResponseModel,
+    OrdersAmount,
+    OrdersOrder,
+    OrdersSubscription,
+    UpdateSubscriptionResponse
+)
+from vkbottle_types.responses.base import BaseBoolInt
 
 
 class OrdersCategory(BaseCategory):
@@ -10,7 +24,7 @@ class OrdersCategory(BaseCategory):
         subscription_id: int,
         pending_cancel: typing.Optional[bool] = None,
         **kwargs
-    ) -> orders.BaseBoolInt:
+    ) -> BaseBoolInt:
         """orders.cancelSubscription method
         :param user_id:
         :param subscription_id:
@@ -19,7 +33,7 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.cancelSubscription", params)
-        model = orders.CancelSubscriptionResponse
+        model = CancelSubscriptionResponse
         return model(**response).response
 
     async def change_state(
@@ -39,7 +53,7 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.changeState", params)
-        model = orders.ChangeStateResponse
+        model = ChangeStateResponse
         return model(**response).response
 
     async def get(
@@ -48,7 +62,7 @@ class OrdersCategory(BaseCategory):
         count: typing.Optional[int] = None,
         test_mode: typing.Optional[bool] = None,
         **kwargs
-    ) -> typing.List[orders.OrdersOrder]:
+    ) -> typing.List[OrdersOrder]:
         """Returns a list of orders.
         :param offset:
         :param count: number of returned orders.
@@ -57,12 +71,12 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.get", params)
-        model = orders.GetResponse
+        model = GetResponse
         return model(**response).response
 
     async def get_amount(
         self, user_id: int, votes: typing.List[str], **kwargs
-    ) -> typing.List[orders.OrdersAmount]:
+    ) -> typing.List[OrdersAmount]:
         """orders.getAmount method
         :param user_id:
         :param votes:
@@ -70,7 +84,7 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.getAmount", params)
-        model = orders.GetAmountResponse
+        model = GetAmountResponse
         return model(**response).response
 
     async def get_by_id(
@@ -79,7 +93,7 @@ class OrdersCategory(BaseCategory):
         order_ids: typing.Optional[typing.List[int]] = None,
         test_mode: typing.Optional[bool] = None,
         **kwargs
-    ) -> typing.List[orders.OrdersOrder]:
+    ) -> typing.List[OrdersOrder]:
         """Returns information about orders by their IDs.
         :param order_id: order ID.
         :param order_ids: order IDs (when information about several orders is requested).
@@ -88,12 +102,12 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.getById", params)
-        model = orders.GetByIdResponse
+        model = GetByIdResponse
         return model(**response).response
 
     async def get_user_subscription_by_id(
         self, user_id: int, subscription_id: int, **kwargs
-    ) -> orders.OrdersSubscription:
+    ) -> OrdersSubscription:
         """orders.getUserSubscriptionById method
         :param user_id:
         :param subscription_id:
@@ -101,24 +115,24 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.getUserSubscriptionById", params)
-        model = orders.GetUserSubscriptionByIdResponse
+        model = GetUserSubscriptionByIdResponse
         return model(**response).response
 
     async def get_user_subscriptions(
         self, user_id: int, **kwargs
-    ) -> orders.GetUserSubscriptionsResponseModel:
+    ) -> GetUserSubscriptionsResponseModel:
         """orders.getUserSubscriptions method
         :param user_id:
         """
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.getUserSubscriptions", params)
-        model = orders.GetUserSubscriptionsResponse
+        model = GetUserSubscriptionsResponse
         return model(**response).response
 
     async def update_subscription(
         self, user_id: int, subscription_id: int, price: int, **kwargs
-    ) -> orders.BaseBoolInt:
+    ) -> BaseBoolInt:
         """orders.updateSubscription method
         :param user_id:
         :param subscription_id:
@@ -127,5 +141,5 @@ class OrdersCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("orders.updateSubscription", params)
-        model = orders.UpdateSubscriptionResponse
+        model = UpdateSubscriptionResponse
         return model(**response).response
