@@ -1,6 +1,6 @@
 import typing
 from .base_category import BaseCategory
-from vkbottle_types.responses import search
+from vkbottle_types.responses.search import GetHintsResponse, GetHintsResponseModel
 
 
 class SearchCategory(BaseCategory):
@@ -13,7 +13,7 @@ class SearchCategory(BaseCategory):
         fields: typing.Optional[typing.List[str]] = None,
         search_global: typing.Optional[bool] = None,
         **kwargs
-    ) -> search.GetHintsResponseModel:
+    ) -> GetHintsResponseModel:
         """Allows the programmer to do a quick search for any substring.
         :param q: Search query string.
         :param offset: Offset for querying specific result subset
@@ -25,5 +25,5 @@ class SearchCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("search.getHints", params)
-        model = search.GetHintsResponse
+        model = GetHintsResponse
         return model(**response).response
